Description Usage Arguments Value
Three options can be set to contol the process of the segmentation.
isNameRec means whether to recognize person names. Default is TRUE.
isNumRec means whether to recognize numbers. Default is TRUE.
isQuantifierRec means whether to combine the numbers and the quantifier. Default is TRUE.
1 |
... |
|
No results.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.